Publications
============

The following publications about *GLASS* exist.

* | *GLASS: Generator for Large Scale Structure*
  | Tessore N., Loureiro A., Joachimi B., von Wietersheim-Kramsta M., Jeffrey N.
  | The Open Journal of Astrophysics 6, 11 (2023)
    (`arXiv <https://arxiv.org/abs/2302.01942>`_,
     `ADS <https://ui.adsabs.harvard.edu/abs/2023OJAp....6E..11T>`_)
